%define         pkgname    gnupg

Summary:	GNU privacy guard - a free PGP replacement
Name:		gnupg2
Version:	2.1.18
Release:	%mkrel 1
License:	GPLv3+
Group:		File tools
URL:		http://www.gnupg.org
Source0:	ftp://ftp.gnupg.org/gcrypt/gnupg/%{pkgname}-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/gnupg/%{pkgname}-%{version}.tar.bz2.sig
Source2:	sysconfig-gnupg2
Source3:	gpg-agent.service
Patch0:		gnupg-1.9.3-use-ImageMagick-for-photo.patch

# Patches from Fedora
Patch100:	gnupg-2.1.17-build.patch

BuildRequires:	openldap-devel
BuildRequires:	sendmail-command
BuildRequires:	libgpg-error-devel >= 1.11
BuildRequires:	libgcrypt-devel >= 1.4.0
BuildRequires:	libassuan-devel >= 2.0.0
BuildRequires:	libksba-devel >= 1.0.7
BuildRequires:	zlib-devel
BuildRequires:	pth-devel >= 2.0.0
BuildRequires:	docbook-utils
BuildRequires:	libreadline-devel
BuildRequires:	libtermcap-devel
BuildRequires:	libcurl-devel
BuildRequires:	pkgconfig(libusb)
BuildRequires:	bzip2-devel
BuildRequires:	libassuan-devel
BuildRequires:	npth-devel
BuildRequires:	gnutls-devel
BuildRequires:	sqlite3-devel



Requires(post):	info-install
Requires(preun): info-install
Requires:	info-install
Requires:	pinentry

# Technically, gnupg2 doesn't need this at all...
Recommends:	gnupg

# dirmngr is now part of gnupg2
Provides:	dirmngr = %{version}-%{release}
Obsoletes:	dirmngr < 1.2.0-1


%description
GnuPG is GNU's tool for secure communication and data storage.
It can be used to encrypt data and to create digital signatures.
It includes an advanced key management facility and is compliant
with the proposed OpenPGP Internet standard as described in RFC2440.

%prep
%setup -q -n %{pkgname}-%{version}
%patch0 -p1


%build
%serverbuild

./autogen.sh

# Add libassuan headers to search path
CPATH=%{_includedir}:%{_includedir}/libassuan2
export CPATH

%configure2_5x \
	--libexecdir=%{_libexecdir}/gnupg2 \
	--enable-symcryptrun \
	--enable-g13 \
	--disable-rpath \
    --disable-systemd \
	--without-capabilities \
	--with-adns=no

%make

# all tests must pass on i586 and x86_64
%check
[[ -n "$GPG_AGENT_INFO" ]] || eval `./agent/gpg-agent --use-standard-socket --daemon --write-env-file gpg-agent-info`
make check
[[ -a gpg-agent-info ]] && kill -0 `cut -d: -f 2 gpg-agent-info`
rm -f gpg-agent-info

%install
%make_install

%__install -D %{SOURCE2} %{buildroot}/%{_sysconfdir}/sysconfig/%{name}
%__install -m 644 -D %{SOURCE3} %{buildroot}/%{_userunitdir}/gpg-agent.service

# remove this from package because the content of options.skel is the
# identical for both gnupg 1/2, except for comment
%__rm -rf %{buildroot}%{_datadir}/gnupg

%__rm -rf %{buildroot}%{_docdir}/gnupg

%find_lang %{name}

%post
%_install_info gnupg.info
#systemd_user_post does only preset, we need it enabled such that at
#all login, the service gets started
if [ $1 -eq 1 ]; then
   systemctl --user --global enable gpg-agent.service
fi


%preun
%_remove_install_info gnupg.info
%systemd_user_preun gnupg-agent.service

%postun
%systemd_postun_with_restart gnupg-agent.service


%files -f %{name}.lang
%doc README NEWS THANKS TODO ChangeLog
%doc doc/FAQ doc/HACKING doc/KEYSERVER doc/OpenPGP doc/TRANSLATE doc/DETAILS
%doc doc/examples
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}
/%{_userunitdir}/gpg-agent.service
%attr(4755,root,root) %{_bindir}/gpgsm
%{_bindir}/gpg-agent
%{_bindir}/gpgconf
%{_bindir}/kbxutil
%{_bindir}/watchgnupg
%{_bindir}/gpg-connect-agent
%{_bindir}/gpgparsemail
%{_bindir}/gpg2
%{_bindir}/gpgv2
%{_bindir}/symcryptrun
%{_bindir}/dirmngr
%{_bindir}/dirmngr-client
%{_bindir}/g13
%{_bindir}/gpgscm
%{_bindir}/gpgtar
%{_sbindir}/addgnupghome
%{_sbindir}/applygnupgdefaults
%{_sbindir}/g13-syshelp
%dir %{_libexecdir}/gnupg2
%{_libexecdir}/gnupg2/gpg-check-pattern
%{_libexecdir}/gnupg2/gpg-preset-passphrase
%{_libexecdir}/gnupg2/gpg-protect-tool
%{_libexecdir}/gnupg2/scdaemon
%{_libexecdir}/gnupg2/dirmngr_ldap
%{_libexecdir}/gnupg2/gpg-wks-client
%{_infodir}/gnupg.info*
%{_mandir}/man1/gpg-agent.1*
%{_mandir}/man1/gpg-connect-agent.1*
%{_mandir}/man1/gpg-preset-passphrase.1*
%{_mandir}/man1/gpg2.1*
%{_mandir}/man1/gpgconf.1*
%{_mandir}/man1/gpgparsemail.1*
%{_mandir}/man1/gpgsm.1*
%{_mandir}/man1/gpgv2.1*
%{_mandir}/man1/scdaemon.1*
%{_mandir}/man1/symcryptrun.1*
%{_mandir}/man1/watchgnupg.1*
%{_mandir}/man1/dirmngr-client.1*
%{_mandir}/man7/gnupg.7*
%{_mandir}/man8/addgnupghome.8*
%{_mandir}/man8/applygnupgdefaults.8*
%{_mandir}/man8/dirmngr.8*


%changelog
* Sat Apr 29 2017 adrianomorselli <adrianomorselli> 2.1.18-1uplos2017
- update
